==> jaysonic-1.2.1.tgz: package/lib/server/ws.js <==
"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var WebSocket = require("ws");

var _ = require("lodash");

var Server = require(".");

var _require = require("../functions"),
    formatResponse = _require.formatResponse;
/**
 * Constructor for Jsonic WS client
 * @class WSClient
 * @constructor
 * @extends Client
 * @param {Object} [options] optional settings for client
 * @return WSClient
 */


var WSServer =
/*#__PURE__*/
function (_Server) {
  _inherits(WSServer, _Server);

  function WSServer(options) {
    var _this;

    _classCallCheck(this, WSServer);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(WSServer).call(this, options));
    _this.connectedClients = [];
    var defaults = {
      port: 8100,
      version: "2.0",
      delimiter: "\n",
      // all the ws options on the github page
      perMessageDeflate: {
        zlibDeflateOptions: {
          // See zlib defaults.
          chunkSize: 1024,
          memLevel: 7,
          level: 3
        },
        zlibInflateOptions: {
          chunkSize: 10 * 1024
        }
      }
    };
    _this.options = _.merge(defaults, options || {});
    return _this;
  }

  _createClass(WSServer, [{
    key: "listen",
    value: function listen() {
      var _this2 = this;

      /**
       * WS server needs to override listen method from parent
       * since the ws library starts listening on instantiation
       */
      return new Promise(function (resolve, reject) {
        try {
          _this2.server = new WebSocket.Server(_this2.options);

          _this2.handleData();

          _this2.handleError();

          resolve();
        } catch (e) {
          reject(e);
        }
      });
    }
  }, {
    key: "handleData",
    value: function handleData() {
      var _this3 = this;

      this.server.on("connection", function (client) {
        _this3.emit("clientConnected", client);

        _this3.connectedClients.push(client);

        client.on("message", function (data) {
          _this3.messageBuffer += data;

          var messages = _this3.messageBuffer.split(_this3.options.delimiter);

          _this3.messageBuffer = "";
          var _iteratorNormalCompletion = true;
          var _didIteratorError = false;
          var _iteratorError = undefined;

          try {
            for (var _iterator = messages[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              var chunk = _step.value;

              if (chunk !== "") {
                Promise.all(_this3.handleValidation(chunk)).then(function (validationResult) {
                  var message = validationResult[1];

                  if (message.batch) {
                    client.send(JSON.stringify(message.batch) + _this3.options.delimiter);
                  } else if (message.notification) {
                    _this3.emit("notify", message.notification);
                  } else {
                    _this3.getResult(message).then(function (result) {
                      return client.send(result + _this3.options.delimiter);
                    })["catch"](function (error) {
                      return client.send(JSON.stringify(error) + _this3.options.delimiter);
                    });
                  }
                })["catch"](function (error) {
                  return client.send(JSON.stringify(error) + _this3.options.delimiter);
                });
              }
            }
          } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion && _iterator["return"] != null) {
                _iterator["return"]();
              }
            } finally {
              if (_didIteratorError) {
                throw _iteratorError;
              }
            }
          }
        });
        client.on("close", function () {
          _this3.emit("clientDisconnected", client);
        });
        client.on("end", function () {
          _this3.emit("clientDisconnected", client);
        });
      });
    }
  }, {
    key: "clientConnected",
    value: function clientConnected(cb) {
      this.on("clientConnected", function (client) {
        return cb({
          host: client.remoteAddress,
          port: client.remotePort
        });
      });
    }
  }, {
    key: "clientDisconnected",
    value: function clientDisconnected(cb) {
      var _this4 = this;

      this.on("clientDisconnected", function (client) {
        var clientIndex = _this4.connectedClients.findIndex(function (c) {
          return client === c;
        });

        if (clientIndex === -1) {
          return "unknown";
        }

        var _this4$connectedClien = _this4.connectedClients.splice(clientIndex, 1),
            _this4$connectedClien2 = _slicedToArray(_this4$connectedClien, 1),
            deletedClient = _this4$connectedClien2[0];

        return cb({
          host: deletedClient.remoteAddress,
          port: deletedClient.remotePort
        });
      });
    } // only available for TCP server

  }, {
    key: "notify",
    value: function notify(method, params) {
      var _this5 = this;

      var response = formatResponse({
        jsonrpc: "2.0",
        method: method,
        params: params
      });

      try {
        this.connectedClients.forEach(function (client) {
          client.send(response + _this5.options.delimiter);
        });
      } catch (e) {
        // was unable to send data to client, possibly disconnected
        this.emit("error", e);
      }
    }
  }]);

  return WSServer;
}(Server);

module.exports = WSServer;

==> jaysonic-1.3.2.tgz: package/lib/server/ws.js <==
"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var WebSocket = require("ws");

var Server = require(".");

var _require = require("../functions"),
    formatResponse = _require.formatResponse;
/**
 * Constructor for Jsonic WS client
 * @class WSClient
 * @constructor
 * @extends Client
 * @param {Object} [options] optional settings for client
 * @return WSClient
 */


var WSServer =
/*#__PURE__*/
function (_Server) {
  _inherits(WSServer, _Server);

  function WSServer(options) {
    var _this;

    _classCallCheck(this, WSServer);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(WSServer).call(this, options));
    _this.connectedClients = [];
    var defaults = {
      port: 8100,
      version: "2.0",
      delimiter: "\n",
      // all the ws options on the github page
      perMessageDeflate: {
        zlibDeflateOptions: {
          // See zlib defaults.
          chunkSize: 1024,
          memLevel: 7,
          level: 3
        },
        zlibInflateOptions: {
          chunkSize: 10 * 1024
        }
      }
    };
    _this.options = _objectSpread({}, defaults, options || {});
    return _this;
  }

  _createClass(WSServer, [{
    key: "listen",
    value: function listen() {
      var _this2 = this;

      /**
       * WS server needs to override listen method from parent
       * since the ws library starts listening on instantiation
       */
      return new Promise(function (resolve, reject) {
        try {
          _this2.server = new WebSocket.Server(_this2.options);

          _this2.handleData();

          _this2.handleError();

          resolve();
        } catch (e) {
          reject(e);
        }
      });
    }
  }, {
    key: "handleData",
    value: function handleData() {
      var _this3 = this;

      this.server.on("connection", function (client) {
        _this3.emit("clientConnected", client);

        _this3.connectedClients.push(client);

        client.on("message", function (data) {
          _this3.messageBuffer.push(data);

          while (!_this3.messageBuffer.isFinished()) {
            var chunk = _this3.messageBuffer.handleData();

            Promise.all(_this3.handleValidation(chunk)).then(function (validationResult) {
              var message = validationResult[1];

              if (message.batch) {
                client.send(JSON.stringify(message.batch) + _this3.options.delimiter);
              } else if (message.notification) {
                _this3.emit("notify", message.notification);
              } else {
                _this3.getResult(message).then(function (result) {
                  return client.send(result + _this3.options.delimiter);
                })["catch"](function (error) {
                  return client.send(JSON.stringify(error) + _this3.options.delimiter);
                });
              }
            })["catch"](function (error) {
              return client.send(JSON.stringify(error) + _this3.options.delimiter);
            });
          }
        });
        client.on("close", function () {
          _this3.emit("clientDisconnected", client);
        });
        client.on("end", function () {
          _this3.emit("clientDisconnected", client);
        });
      });
    }
  }, {
    key: "clientConnected",
    value: function clientConnected(cb) {
      this.on("clientConnected", function (client) {
        return cb({
          host: client.remoteAddress,
          port: client.remotePort
        });
      });
    }
  }, {
    key: "clientDisconnected",
    value: function clientDisconnected(cb) {
      var _this4 = this;

      this.on("clientDisconnected", function (client) {
        var clientIndex = _this4.connectedClients.findIndex(function (c) {
          return client === c;
        });

        if (clientIndex === -1) {
          return "unknown";
        }

        var _this4$connectedClien = _this4.connectedClients.splice(clientIndex, 1),
            _this4$connectedClien2 = _slicedToArray(_this4$connectedClien, 1),
            deletedClient = _this4$connectedClien2[0];

        return cb({
          host: deletedClient.remoteAddress,
          port: deletedClient.remotePort
        });
      });
    } // only available for TCP server

  }, {
    key: "notify",
    value: function notify(method, params) {
      var _this5 = this;

      var response = formatResponse({
        jsonrpc: "2.0",
        method: method,
        params: params
      });

      try {
        this.connectedClients.forEach(function (client) {
          client.send(response + _this5.options.delimiter);
        });
      } catch (e) {
        // was unable to send data to client, possibly disconnected
        this.emit("error", e);
      }
    }
  }]);

  return WSServer;
}(Server);

module.exports = WSServer;
